@@ -61,7 +61,8 @@ void AutoAway::timeoutReached(int id)
     if (id == m_awayTimeoutId) {
         if (m_globalPresence->currentPresence().type() != Tp::Presence::away().type() &&
             m_globalPresence->currentPresence().type() != Tp::Presence::xa().type() &&
-            m_globalPresence->currentPresence().type() != Tp::Presence::hidden().type()) {
+            m_globalPresence->currentPresence().type() != Tp::Presence::hidden().type() &&
+            m_globalPresence->currentPresence().type() != Tp::Presence::offline().type()) {
             m_awayMessage.replace(QLatin1String("%time"), QDateTime::currentDateTimeUtc().toString(QLatin1String("hh:mm:ss (%t)")), Qt::CaseInsensitive);
             setRequestedPresence(Tp::Presence::away(m_awayMessage));
             setActive(true);
